<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Phone.System.Profile

Windows Runtime (WinRT) APIs for for the `Windows.Phone.System.Profile` namespace.

This package provides the `winrt.windows.phone.system.profile` module.
